<?php

if ( strpos( $_SERVER['HTTP_HOST'], '127.0.0.1' ) !== false
|| strpos( $_SERVER['HTTP_HOST'], '.local' ) !== false ) {
	define( 'TRACKMAN_BASE_URL', 'http://localhost:8000' );
} else {
	define( 'TRACKMAN_BASE_URL', 'https://app.adtechthai.com' );
}

// Add admin menu
function trackman_add_menu() {
	// add_menu_page( 'TrackMan', 'TrackMan', 'manage_options', 'trackman', 'trackman_page', '', 58);
	add_menu_page( 'TrackMan', 'TrackMan', 'manage_options', 'trackman', 'trackman_page', 'dashicons-visibility', 58);
	add_submenu_page( 'trackman', 'Settings', 'Settings', 'manage_options', 'trackman', 'trackman_page' );
	
	add_submenu_page( 'trackman', 'WooCommerce Integration', 'WooCommerce Integration', 'manage_options', 'woocommerce-integration', 'woocommerce_integration_page' );
	
	add_submenu_page( 'trackman', 'WooFunnels Integration', 'WooFunnels Integration', 'manage_options', 'woofunnels-integration', 'woofunnels_integration_page' );
}
add_action( 'admin_menu', 'trackman_add_menu' );

// Add form to admin page
function trackman_page() {
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	?>
	<style type='text/css'>
		.form-control {
			width: 100%;
		}
	</style>
	<div class="wrap">
		<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
		<form method="post" action="options.php">
			<?php settings_fields( 'trackman-settings-group' ); ?>
			<?php do_settings_sections( 'trackman-settings-group' ); ?>
			<table class="form-table">
				<tr>
					<th scope="row"><label for="trackman-public-key"><?php _e( 'TrackMan Public Key', 'trackman' ); ?></label></th>
					<td>
						<input type="text" id="trackman-public-key" name="trackman_public_key" value="<?php echo esc_attr( get_option( 'trackman_public_key' ) ); ?>" class='form-control'>
						<!-- add a field hint: use comma for multiple pulic keys -->
						<small>
							<?php _e( 'Enter your TrackMan public key. You can find your public key in the TrackMan dashboard.', 'trackman' ); ?>
							<strong>
								<?php _e( 'Use comma for multiple public keys.', 'trackman' ); ?>
							</strong>
							<a href="https://app.adtechthai.com" target="_blank">Go to Dashboard</a>
						</small>
					</td>
				</tr>
			</table>
			<?php submit_button( 'Save' ); ?>
		</form>
	</div>
	<?php
}

function woocommerce_integration_page() {
    ?>
	<style type='text/css'>
		.form-control {
			width: 100%;
		}
	</style>
	<div class="wrap">
		<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
		<p>
			<?php _e( 'TrackMan WooCommerce Integration', 'trackman' ); ?>
		</p>
		<!-- add a checkbox config: "Send WooCommerce purchase data to TrackMan" -->
		<form method="post" action="options.php">
			<?php settings_fields( 'trackman-woo-settings-group' ); ?>
			<?php do_settings_sections( 'trackman-woo-settings-group' ); ?>
			<table class="form-table">
				<tr>
					<th scope="row"><label for="trackman-send-woocommerce-data"><?php _e( 'Automatically Send WooCommerce (AddToCart, InitiateCheckout, and Purchase) data to TrackMan', 'trackman' ); ?></label></th>
					<td>
						<label>
							<input type="checkbox" id="trackman-send-woocommerce-data" name="trackman_woocommerce_autosend" value="1" <?php checked( 1, get_option( 'trackman_woocommerce_autosend' ), true ); ?>>
						<?php _e( 'Send WooCommerce event data to TrackMan AUTOMATICALLY.', 'trackman' ); ?>
						</label>
					</td>
				</tr>
			</table>
			<?php submit_button( 'Save' ); ?>
		</form>
	</div>
	<?php
}

function woofunnels_integration_page() {

	if ( !is_plugin_active( 'funnel-builder/funnel-builder.php' ) ) {
		?>
		<div class="wrap">
			<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
			<p>
				<?php _e( 'WooFunnels (Funnel Builder, plugin folder must named "funnel-builder") is <b>NOT</b> installed or activated.', 'trackman' ); ?>
			</p>
		</div>
		<?php
		return;
	}

    // Code for WooFunnels Integration page
	$all_funnels = get_all_woofunnels_funnels();
	// var_dump($all_funnels);
	?>
	<style type='text/css'>
		.form-control {
			width: 100%;
		}
		#wpwrap {
			background: transparent !important; /* but why? */
		}
	</style>
	<div class="wrap">
		<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
		<p>
			<?php _e( 'Enter your TrackMan public key for each funnel. You can find your public key in the TrackMan dashboard.', 'trackman' ); ?>
			<a href="https://app.adtechthai.com" target="_blank">Go to Dashboard</a>
		</p>
		<?php
			$value_arr = get_option( 'trackman_wf_public_keys' );
		?>
		<!--
			create 2 columns for each funnel
			1st column: funnel name
			2nd column: textarea for public key
			after all funnels, add a submit button
		-->
		<form method="post" action="options.php">
			<?php settings_fields( 'trackman-wf-settings-group' ); ?>
			<?php do_settings_sections( 'trackman-wf-settings-group' ); ?>
			<table class="form-table">
				<?php foreach($all_funnels as $funnel_data): ?>
					<?php
						$funnel_id = $funnel_data['id'];
						$this_field_value = $value_arr[$funnel_id];
					?>
					<tr>
						<td style="width: 200px;">
							<?php echo $funnel_data['title']; ?> (ID: <?php echo $funnel_data['id']; ?>)
						</td>
						<td>
							<input type='text' id="trackman-public-key-<?= $funnel_data['id'] ?>" name="trackman_wf_public_keys[<?= $funnel_data['id'] ?>]" value="<?php echo $this_field_value ?>" class='form-control' placeholder="Insert a public key, or multiple keys with commas separated e.g. <public key 1>,<public key 2>">
						</td>
					</tr>
				<?php endforeach; ?>
			</table>
			<?php submit_button( 'Save' ); ?>
		</form>
	</div>
	<?php
}

// Register settings
function trackman_register_settings() {
	register_setting( 'trackman-settings-group', 'trackman_public_key' );
	register_setting( 'trackman-woo-settings-group', 'trackman_woocommerce_autosend' );
	register_setting( 'trackman-wf-settings-group', 'trackman_wf_public_keys' );

}
add_action( 'admin_init', 'trackman_register_settings' );

function get_all_woofunnels_funnels() {
    global $wpdb;

    // Use the default table name for WooFunnels funnels
    $table_name = $wpdb->prefix . 'bwf_funnels';

    // Make sure the table exists
    if ($wpdb->get_var("SHOW TABLES LIKE '{$table_name}'") != $table_name) {
        return array(); // If the table doesn't exist, return an empty array
    }

    // Prepare the SQL query to fetch all funnels from the table
    $sql = "SELECT * FROM {$table_name}";

    // Execute the query and get the results as an associative array
    $results = $wpdb->get_results($sql, ARRAY_A);

    return $results;
}