<?php
// add a hook to inject code to woocommerce's cart page
add_action( 'woocommerce_after_cart', 'trackman_add_fb_pixel_to_cart' );

// inject code to woocommerce's cart page
function trackman_add_fb_pixel_to_cart() {

	$trackman_public_keys_array = explode( ',', get_option( 'trackman_public_key' ) );

    // if the cookie exists, do not send the event
    if (isset($_COOKIE['trackman_addtocart'])) {
		return;
	}

	// skip this if options 'trackman_woocommerce_autosend' is false or null
	if( get_option( 'trackman_woocommerce_autosend' ) == false || get_option( 'trackman_woocommerce_autosend' ) == null ) {
		return;
	}

	// get the current cart contents
	$cart_contents = WC()->cart->get_cart();
	// initialize an empty array to store product ids
	$product_ids = array();
	// loop through the cart contents
	foreach ( $cart_contents as $cart_item_key => $cart_item ) {
		// get the product id from the cart item
		$product_id = $cart_item['product_id'];
		// push the product id into the product ids array
		array_push($product_ids, $product_id);
	}
	// join the product ids array with comma (,) to create a string of product ids
	$product_ids = implode(',', $product_ids);
	// get the current cart total
	$cart_total = WC()->cart->get_total();
	$cart_total_float = floatval($cart_total);
	// get the current cart count
	$cart_count = WC()->cart->get_cart_contents_count();
	// get cart currency
	$cart_currency = get_woocommerce_currency();
	// product names
	$product_names = array();
	// loop through the cart contents
	foreach ( $cart_contents as $cart_item_key => $cart_item ) {
		// get the product id from the cart item
		$product_name = $cart_item['data']->get_name();
		// push the product id into the product ids array
		array_push($product_names, $product_name);
	}
	// join the product ids array with comma (,) to create a string of product ids
	$product_names = implode(',', $product_names);

    $eventId = "event.id." . date("YmdHis") . rand(10000, 99999);

	// prepare eventData as json to send to Javascript
	$eventData = [
		'event_name' => 'AddToCart',
		'event_time' => time(),
		"action_source" => "website",
		"opt_out" => false,
		'event_source_url' => $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'],
		'event_id' => $eventId,
		'user_data' => [
			'client_ip_address' => $_SERVER['REMOTE_ADDR'],
			'client_user_agent' => $_SERVER['HTTP_USER_AGENT'],
		],
		'custom_data' => [
			'content_name' => $product_names,
			'content_category' => 'ecommerce',
			'content_ids' => $product_ids,
			'content_type' => 'product',
			'currency' => get_woocommerce_currency(),
			'value' => $cart_total_float,
			'num_items' => $cart_count,
		]
	];

	?>
	<script type="text/javascript">
		window.addEventListener("DOMContentLoaded", function (event) {
			<?php foreach( $trackman_public_keys_array as $public_key ): ?>
				tmfire('<?= $public_key ?>', <?= json_encode($eventData) ?>);
			<?php endforeach; ?>
			document.cookie = "trackman_addtocart=true;max-age=600";
		});
	</script>
	<?php
}